@@ -71,11 +71,6 @@ show_authors = False
 
 # -- Options for HTML output ---------------------------------------------------
 
-# The theme to use for HTML and HTML Help pages.  See the documentation for
-# a list of builtin themes.
-html_theme_path = ['.']
-html_theme = '_theme'
-
 # Custom sidebar templates, maps document names to template names.
 html_sidebars = {
     'index':    ['sidebarlinks.html', 'localtoc.html', 'searchbox.html', 'sourcelink.html'],
