@@ -12,25 +12,23 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
 import json
-import multiprocessing
 import socket
 import time
 
 import eventlet
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_service import service
 import psutil
 
 from murano.api import v1
 from murano.api.v1 import request_statistics
+from murano.common import config
 from murano.db.services import stats as db_stats
+from murano.openstack.common.gettextutils import _  # noqa
+from murano.openstack.common import log as logging
+from murano.openstack.common import service
 
-CONF = cfg.CONF
 
-CONF_STATS = CONF.stats
+CONF_STATS = config.CONF.stats
 LOG = logging.getLogger(__name__)
 
 
@@ -57,13 +55,13 @@ class StatsCollectingService(service.Service):
 
     def update_stats(self):
         LOG.debug("Updating statistic information.")
-        LOG.debug("Stats object: {stats}".format(stats=v1.stats))
-        LOG.debug("Stats: (Requests: {amount}  Errors: {error}  "
-                  "Ave.Res.Time {time:2.4f}\n Per tenant: {req_count})".format(
-                      amount=v1.stats.request_count,
-                      error=v1.stats.error_count,
-                      time=v1.stats.average_time,
-                      req_count=v1.stats.requests_per_tenant))
+        LOG.debug("Stats object: %s" % v1.stats)
+        LOG.debug("Stats: Requests:%s  Errors: %s Ave.Res.Time %2.4f\n"
+                  "Per tenant: %s" %
+                  (v1.stats.request_count,
+                   v1.stats.error_count,
+                   v1.stats.average_time,
+                   v1.stats.requests_per_tenant))
         try:
             stats = self._stats_db.get_stats_by_host(self._hostname)
             if stats is None:
@@ -72,7 +70,7 @@ class StatsCollectingService(service.Service):
                                       v1.stats.error_count,
                                       v1.stats.average_time,
                                       v1.stats.requests_per_tenant,
-                                      multiprocessing.cpu_count(),
+                                      psutil.NUM_CPUS,
                                       psutil.cpu_percent())
                 return
 
@@ -93,5 +91,5 @@ class StatsCollectingService(service.Service):
             stats.cpu_percent = psutil.cpu_percent()
             self._stats_db.update(self._hostname, stats)
         except Exception as e:
-            LOG.exception("Failed to get statistics object from a "
-                          "database. {error_code}".format(error_code=e))
+            LOG.error(_("Failed to get statistics object "
+                        "form a database. %s" % e))
